# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: milvus.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from . import schema_pb2 as schema__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='milvus.proto',
  package='milvus.proto.milvus',
  syntax='proto3',
  serialized_options=_b('Z@github.com/zilliztech/milvus-distributed/internal/proto/milvuspb'),
  serialized_pb=_b('\n\x0cmilvus.proto\x12\x13milvus.proto.milvus\x1a\x0c\x63ommon.proto\x1a\x0cschema.proto\"\x7f\n\x17\x43reateCollectionRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x0e\n\x06schema\x18\x04 \x01(\x0c\"m\n\x15\x44ropCollectionRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\"l\n\x14HasCollectionRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\"J\n\x0c\x42oolResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\r\n\x05value\x18\x02 \x01(\x08\"L\n\x0eStringResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\r\n\x05value\x18\x02 \x01(\t\"\x87\x01\n\x19\x44\x65scribeCollectionRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x14\n\x0c\x63ollectionID\x18\x04 \x01(\x03\"\x96\x01\n\x1a\x44\x65scribeCollectionResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x35\n\x06schema\x18\x02 \x01(\x0b\x32%.milvus.proto.schema.CollectionSchema\x12\x14\n\x0c\x63ollectionID\x18\x03 \x01(\x03\"m\n\x15LoadCollectionRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\"p\n\x18ReleaseCollectionRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\"v\n\x1eGetCollectionStatisticsRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\"\x80\x01\n\x1fGetCollectionStatisticsResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x30\n\x05stats\x18\x02 \x03(\x0b\x32!.milvus.proto.common.KeyValuePair\"U\n\x16ShowCollectionsRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\"`\n\x17ShowCollectionsResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x18\n\x10\x63ollection_names\x18\x02 \x03(\t\"\x86\x01\n\x16\x43reatePartitionRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x16\n\x0epartition_name\x18\x04 \x01(\t\"\x84\x01\n\x14\x44ropPartitionRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x16\n\x0epartition_name\x18\x04 \x01(\t\"\x83\x01\n\x13HasPartitionRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x16\n\x0epartition_name\x18\x04 \x01(\t\"\x86\x01\n\x15LoadPartitionsRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x17\n\x0fpartition_names\x18\x04 \x03(\t\"\x89\x01\n\x18ReleasePartitionsRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x17\n\x0fpartition_names\x18\x04 \x03(\t\"\x8d\x01\n\x1dGetPartitionStatisticsRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x16\n\x0epartition_name\x18\x04 \x01(\t\"\x7f\n\x1eGetPartitionStatisticsResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x30\n\x05stats\x18\x02 \x03(\x0b\x32!.milvus.proto.common.KeyValuePair\"\x83\x01\n\x15ShowPartitionsRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x14\n\x0c\x63ollectionID\x18\x04 \x01(\x03\"t\n\x16ShowPartitionsResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x17\n\x0fpartition_names\x18\x02 \x03(\t\x12\x14\n\x0cpartitionIDs\x18\x03 \x03(\x03\"m\n\x16\x44\x65scribeSegmentRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x14\n\x0c\x63ollectionID\x18\x02 \x01(\x03\x12\x11\n\tsegmentID\x18\x03 \x01(\x03\"~\n\x17\x44\x65scribeSegmentResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x0f\n\x07indexID\x18\x02 \x01(\x03\x12\x0f\n\x07\x62uildID\x18\x03 \x01(\x03\x12\x14\n\x0c\x65nable_index\x18\x04 \x01(\x08\"l\n\x13ShowSegmentsRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x14\n\x0c\x63ollectionID\x18\x02 \x01(\x03\x12\x13\n\x0bpartitionID\x18\x03 \x01(\x03\"W\n\x14ShowSegmentsResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x12\n\nsegmentIDs\x18\x02 \x03(\x03\"\xb7\x01\n\x12\x43reateIndexRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x12\n\nfield_name\x18\x04 \x01(\t\x12\x37\n\x0c\x65xtra_params\x18\x05 \x03(\x0b\x32!.milvus.proto.common.KeyValuePair\"\x94\x01\n\x14\x44\x65scribeIndexRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x12\n\nfield_name\x18\x04 \x01(\t\x12\x12\n\nindex_name\x18\x05 \x01(\t\"j\n\x10IndexDescription\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12\x0f\n\x07indexID\x18\x02 \x01(\x03\x12\x31\n\x06params\x18\x03 \x03(\x0b\x32!.milvus.proto.common.KeyValuePair\"\x87\x01\n\x15\x44\x65scribeIndexResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x41\n\x12index_descriptions\x18\x02 \x03(\x0b\x32%.milvus.proto.milvus.IndexDescription\"\x94\x01\n\x14GetIndexStateRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x12\n\nfield_name\x18\x04 \x01(\t\x12\x12\n\nindex_name\x18\x05 \x01(\t\"t\n\x15GetIndexStateResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12.\n\x05state\x18\x02 \x01(\x0e\x32\x1f.milvus.proto.common.IndexState\"\x90\x01\n\x10\x44ropIndexRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x12\n\nfield_name\x18\x04 \x01(\t\x12\x12\n\nindex_name\x18\x05 \x01(\t\"\xbd\x01\n\rInsertRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x16\n\x0epartition_name\x18\x04 \x01(\t\x12+\n\x08row_data\x18\x05 \x03(\x0b\x32\x19.milvus.proto.common.Blob\x12\x11\n\thash_keys\x18\x06 \x03(\r\"e\n\x0eInsertResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x13\n\x0browID_begin\x18\x02 \x01(\x03\x12\x11\n\trowID_end\x18\x03 \x01(\x03\"c\n\x10PlaceholderValue\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x32\n\x04type\x18\x02 \x01(\x0e\x32$.milvus.proto.milvus.PlaceholderType\x12\x0e\n\x06values\x18\x03 \x03(\x0c\"O\n\x10PlaceholderGroup\x12;\n\x0cplaceholders\x18\x01 \x03(\x0b\x32%.milvus.proto.milvus.PlaceholderValue\"\xa6\x01\n\rSearchRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x03 \x01(\t\x12\x17\n\x0fpartition_names\x18\x04 \x03(\t\x12\x0b\n\x03\x64sl\x18\x05 \x01(\t\x12\x19\n\x11placeholder_group\x18\x06 \x01(\x0c\"5\n\x04Hits\x12\x0b\n\x03IDs\x18\x01 \x03(\x03\x12\x10\n\x08row_data\x18\x02 \x03(\x0c\x12\x0e\n\x06scores\x18\x03 \x03(\x02\"J\n\rSearchResults\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x0c\n\x04hits\x18\x02 \x03(\x0c\"e\n\x0c\x46lushRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0f\n\x07\x64\x62_name\x18\x02 \x01(\t\x12\x18\n\x10\x63ollection_names\x18\x03 \x03(\t\"\xe9\x01\n\x15PersistentSegmentInfo\x12\x11\n\tsegmentID\x18\x01 \x01(\x03\x12\x14\n\x0c\x63ollectionID\x18\x02 \x01(\x03\x12\x13\n\x0bpartitionID\x18\x03 \x01(\x03\x12\x11\n\topen_time\x18\x04 \x01(\x04\x12\x13\n\x0bsealed_time\x18\x05 \x01(\x04\x12\x14\n\x0c\x66lushed_time\x18\x06 \x01(\x04\x12\x10\n\x08num_rows\x18\x07 \x01(\x03\x12\x10\n\x08mem_size\x18\x08 \x01(\x03\x12\x30\n\x05state\x18\t \x01(\x0e\x32!.milvus.proto.common.SegmentState\"u\n\x1fGetPersistentSegmentInfoRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0e\n\x06\x64\x62Name\x18\x02 \x01(\t\x12\x16\n\x0e\x63ollectionName\x18\x03 \x01(\t\"\x8a\x01\n GetPersistentSegmentInfoResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x39\n\x05infos\x18\x02 \x03(\x0b\x32*.milvus.proto.milvus.PersistentSegmentInfo\"\x99\x01\n\x10QuerySegmentInfo\x12\x11\n\tsegmentID\x18\x01 \x01(\x03\x12\x14\n\x0c\x63ollectionID\x18\x02 \x01(\x03\x12\x13\n\x0bpartitionID\x18\x03 \x01(\x03\x12\x10\n\x08mem_size\x18\x04 \x01(\x03\x12\x10\n\x08num_rows\x18\x05 \x01(\x03\x12\x12\n\nindex_name\x18\x06 \x01(\t\x12\x0f\n\x07indexID\x18\x07 \x01(\x03\"p\n\x1aGetQuerySegmentInfoRequest\x12*\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.MsgBase\x12\x0e\n\x06\x64\x62Name\x18\x02 \x01(\t\x12\x16\n\x0e\x63ollectionName\x18\x03 \x01(\t\"\x80\x01\n\x1bGetQuerySegmentInfoResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x34\n\x05infos\x18\x02 \x03(\x0b\x32%.milvus.proto.milvus.QuerySegmentInfo\"\x15\n\x13RegisterLinkRequest\"r\n\x14RegisterLinkResponse\x12-\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1c.milvus.proto.common.Address\x12+\n\x06status\x18\x02 \x01(\x0b\x32\x1b.milvus.proto.common.Status*>\n\x0fPlaceholderType\x12\x08\n\x04None\x10\x00\x12\x10\n\x0c\x42inaryVector\x10\x64\x12\x0f\n\x0b\x46loatVector\x10\x65\x32\x8d\x14\n\rMilvusService\x12_\n\x10\x43reateCollection\x12,.milvus.proto.milvus.CreateCollectionRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12[\n\x0e\x44ropCollection\x12*.milvus.proto.milvus.DropCollectionRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12_\n\rHasCollection\x12).milvus.proto.milvus.HasCollectionRequest\x1a!.milvus.proto.milvus.BoolResponse\"\x00\x12[\n\x0eLoadCollection\x12*.milvus.proto.milvus.LoadCollectionRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12\x61\n\x11ReleaseCollection\x12-.milvus.proto.milvus.ReleaseCollectionRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12w\n\x12\x44\x65scribeCollection\x12..milvus.proto.milvus.DescribeCollectionRequest\x1a/.milvus.proto.milvus.DescribeCollectionResponse\"\x00\x12\x86\x01\n\x17GetCollectionStatistics\x12\x33.milvus.proto.milvus.GetCollectionStatisticsRequest\x1a\x34.milvus.proto.milvus.GetCollectionStatisticsResponse\"\x00\x12n\n\x0fShowCollections\x12+.milvus.proto.milvus.ShowCollectionsRequest\x1a,.milvus.proto.milvus.ShowCollectionsResponse\"\x00\x12]\n\x0f\x43reatePartition\x12+.milvus.proto.milvus.CreatePartitionRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12Y\n\rDropPartition\x12).milvus.proto.milvus.DropPartitionRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12]\n\x0cHasPartition\x12(.milvus.proto.milvus.HasPartitionRequest\x1a!.milvus.proto.milvus.BoolResponse\"\x00\x12[\n\x0eLoadPartitions\x12*.milvus.proto.milvus.LoadPartitionsRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12\x61\n\x11ReleasePartitions\x12-.milvus.proto.milvus.ReleasePartitionsRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12\x83\x01\n\x16GetPartitionStatistics\x12\x32.milvus.proto.milvus.GetPartitionStatisticsRequest\x1a\x33.milvus.proto.milvus.GetPartitionStatisticsResponse\"\x00\x12k\n\x0eShowPartitions\x12*.milvus.proto.milvus.ShowPartitionsRequest\x1a+.milvus.proto.milvus.ShowPartitionsResponse\"\x00\x12U\n\x0b\x43reateIndex\x12\'.milvus.proto.milvus.CreateIndexRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12h\n\rDescribeIndex\x12).milvus.proto.milvus.DescribeIndexRequest\x1a*.milvus.proto.milvus.DescribeIndexResponse\"\x00\x12h\n\rGetIndexState\x12).milvus.proto.milvus.GetIndexStateRequest\x1a*.milvus.proto.milvus.GetIndexStateResponse\"\x00\x12Q\n\tDropIndex\x12%.milvus.proto.milvus.DropIndexRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12S\n\x06Insert\x12\".milvus.proto.milvus.InsertRequest\x1a#.milvus.proto.milvus.InsertResponse\"\x00\x12R\n\x06Search\x12\".milvus.proto.milvus.SearchRequest\x1a\".milvus.proto.milvus.SearchResults\"\x00\x12I\n\x05\x46lush\x12!.milvus.proto.milvus.FlushRequest\x1a\x1b.milvus.proto.common.Status\"\x00\x12\x89\x01\n\x18GetPersistentSegmentInfo\x12\x34.milvus.proto.milvus.GetPersistentSegmentInfoRequest\x1a\x35.milvus.proto.milvus.GetPersistentSegmentInfoResponse\"\x00\x12z\n\x13GetQuerySegmentInfo\x12/.milvus.proto.milvus.GetQuerySegmentInfoRequest\x1a\x30.milvus.proto.milvus.GetQuerySegmentInfoResponse\"\x00\x12\x65\n\x0cRegisterLink\x12(.milvus.proto.milvus.RegisterLinkRequest\x1a).milvus.proto.milvus.RegisterLinkResponse\"\x00\x32u\n\x0cProxyService\x12\x65\n\x0cRegisterLink\x12(.milvus.proto.milvus.RegisterLinkRequest\x1a).milvus.proto.milvus.RegisterLinkResponse\"\x00\x42\x42Z@github.com/zilliztech/milvus-distributed/internal/proto/milvuspbb\x06proto3')
  ,
  dependencies=[common__pb2.DESCRIPTOR,schema__pb2.DESCRIPTOR,])

_PLACEHOLDERTYPE = _descriptor.EnumDescriptor(
  name='PlaceholderType',
  full_name='milvus.proto.milvus.PlaceholderType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='None', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BinaryVector', index=1, number=100,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FloatVector', index=2, number=101,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6082,
  serialized_end=6144,
)
_sym_db.RegisterEnumDescriptor(_PLACEHOLDERTYPE)

PlaceholderType = enum_type_wrapper.EnumTypeWrapper(_PLACEHOLDERTYPE)
globals()['None'] = 0
BinaryVector = 100
FloatVector = 101



_CREATECOLLECTIONREQUEST = _descriptor.Descriptor(
  name='CreateCollectionRequest',
  full_name='milvus.proto.milvus.CreateCollectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.CreateCollectionRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.CreateCollectionRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.CreateCollectionRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='schema', full_name='milvus.proto.milvus.CreateCollectionRequest.schema', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=65,
  serialized_end=192,
)


_DROPCOLLECTIONREQUEST = _descriptor.Descriptor(
  name='DropCollectionRequest',
  full_name='milvus.proto.milvus.DropCollectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.DropCollectionRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.DropCollectionRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.DropCollectionRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=194,
  serialized_end=303,
)


_HASCOLLECTIONREQUEST = _descriptor.Descriptor(
  name='HasCollectionRequest',
  full_name='milvus.proto.milvus.HasCollectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.HasCollectionRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.HasCollectionRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.HasCollectionRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=305,
  serialized_end=413,
)


_BOOLRESPONSE = _descriptor.Descriptor(
  name='BoolResponse',
  full_name='milvus.proto.milvus.BoolResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.milvus.BoolResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='milvus.proto.milvus.BoolResponse.value', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=415,
  serialized_end=489,
)


_STRINGRESPONSE = _descriptor.Descriptor(
  name='StringResponse',
  full_name='milvus.proto.milvus.StringResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.milvus.StringResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='milvus.proto.milvus.StringResponse.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=491,
  serialized_end=567,
)


_DESCRIBECOLLECTIONREQUEST = _descriptor.Descriptor(
  name='DescribeCollectionRequest',
  full_name='milvus.proto.milvus.DescribeCollectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.DescribeCollectionRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.DescribeCollectionRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.DescribeCollectionRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collectionID', full_name='milvus.proto.milvus.DescribeCollectionRequest.collectionID', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=570,
  serialized_end=705,
)


_DESCRIBECOLLECTIONRESPONSE = _descriptor.Descriptor(
  name='DescribeCollectionResponse',
  full_name='milvus.proto.milvus.DescribeCollectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.milvus.DescribeCollectionResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='schema', full_name='milvus.proto.milvus.DescribeCollectionResponse.schema', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collectionID', full_name='milvus.proto.milvus.DescribeCollectionResponse.collectionID', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=708,
  serialized_end=858,
)


_LOADCOLLECTIONREQUEST = _descriptor.Descriptor(
  name='LoadCollectionRequest',
  full_name='milvus.proto.milvus.LoadCollectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.LoadCollectionRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.LoadCollectionRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.LoadCollectionRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=860,
  serialized_end=969,
)


_RELEASECOLLECTIONREQUEST = _descriptor.Descriptor(
  name='ReleaseCollectionRequest',
  full_name='milvus.proto.milvus.ReleaseCollectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.ReleaseCollectionRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.ReleaseCollectionRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.ReleaseCollectionRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=971,
  serialized_end=1083,
)


_GETCOLLECTIONSTATISTICSREQUEST = _descriptor.Descriptor(
  name='GetCollectionStatisticsRequest',
  full_name='milvus.proto.milvus.GetCollectionStatisticsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.GetCollectionStatisticsRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.GetCollectionStatisticsRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.GetCollectionStatisticsRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1085,
  serialized_end=1203,
)


_GETCOLLECTIONSTATISTICSRESPONSE = _descriptor.Descriptor(
  name='GetCollectionStatisticsResponse',
  full_name='milvus.proto.milvus.GetCollectionStatisticsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.milvus.GetCollectionStatisticsResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stats', full_name='milvus.proto.milvus.GetCollectionStatisticsResponse.stats', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1206,
  serialized_end=1334,
)


_SHOWCOLLECTIONSREQUEST = _descriptor.Descriptor(
  name='ShowCollectionsRequest',
  full_name='milvus.proto.milvus.ShowCollectionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.ShowCollectionsRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.ShowCollectionsRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1336,
  serialized_end=1421,
)


_SHOWCOLLECTIONSRESPONSE = _descriptor.Descriptor(
  name='ShowCollectionsResponse',
  full_name='milvus.proto.milvus.ShowCollectionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.milvus.ShowCollectionsResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_names', full_name='milvus.proto.milvus.ShowCollectionsResponse.collection_names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1423,
  serialized_end=1519,
)


_CREATEPARTITIONREQUEST = _descriptor.Descriptor(
  name='CreatePartitionRequest',
  full_name='milvus.proto.milvus.CreatePartitionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.CreatePartitionRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.CreatePartitionRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.CreatePartitionRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partition_name', full_name='milvus.proto.milvus.CreatePartitionRequest.partition_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1522,
  serialized_end=1656,
)


_DROPPARTITIONREQUEST = _descriptor.Descriptor(
  name='DropPartitionRequest',
  full_name='milvus.proto.milvus.DropPartitionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.DropPartitionRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.DropPartitionRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.DropPartitionRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partition_name', full_name='milvus.proto.milvus.DropPartitionRequest.partition_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1659,
  serialized_end=1791,
)


_HASPARTITIONREQUEST = _descriptor.Descriptor(
  name='HasPartitionRequest',
  full_name='milvus.proto.milvus.HasPartitionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.HasPartitionRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.HasPartitionRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.HasPartitionRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partition_name', full_name='milvus.proto.milvus.HasPartitionRequest.partition_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1794,
  serialized_end=1925,
)


_LOADPARTITIONSREQUEST = _descriptor.Descriptor(
  name='LoadPartitionsRequest',
  full_name='milvus.proto.milvus.LoadPartitionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.LoadPartitionsRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.LoadPartitionsRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.LoadPartitionsRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partition_names', full_name='milvus.proto.milvus.LoadPartitionsRequest.partition_names', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1928,
  serialized_end=2062,
)


_RELEASEPARTITIONSREQUEST = _descriptor.Descriptor(
  name='ReleasePartitionsRequest',
  full_name='milvus.proto.milvus.ReleasePartitionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.ReleasePartitionsRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.ReleasePartitionsRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.ReleasePartitionsRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partition_names', full_name='milvus.proto.milvus.ReleasePartitionsRequest.partition_names', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2065,
  serialized_end=2202,
)


_GETPARTITIONSTATISTICSREQUEST = _descriptor.Descriptor(
  name='GetPartitionStatisticsRequest',
  full_name='milvus.proto.milvus.GetPartitionStatisticsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.GetPartitionStatisticsRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.GetPartitionStatisticsRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.GetPartitionStatisticsRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partition_name', full_name='milvus.proto.milvus.GetPartitionStatisticsRequest.partition_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2205,
  serialized_end=2346,
)


_GETPARTITIONSTATISTICSRESPONSE = _descriptor.Descriptor(
  name='GetPartitionStatisticsResponse',
  full_name='milvus.proto.milvus.GetPartitionStatisticsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.milvus.GetPartitionStatisticsResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stats', full_name='milvus.proto.milvus.GetPartitionStatisticsResponse.stats', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2348,
  serialized_end=2475,
)


_SHOWPARTITIONSREQUEST = _descriptor.Descriptor(
  name='ShowPartitionsRequest',
  full_name='milvus.proto.milvus.ShowPartitionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.ShowPartitionsRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.ShowPartitionsRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.ShowPartitionsRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collectionID', full_name='milvus.proto.milvus.ShowPartitionsRequest.collectionID', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2478,
  serialized_end=2609,
)


_SHOWPARTITIONSRESPONSE = _descriptor.Descriptor(
  name='ShowPartitionsResponse',
  full_name='milvus.proto.milvus.ShowPartitionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.milvus.ShowPartitionsResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partition_names', full_name='milvus.proto.milvus.ShowPartitionsResponse.partition_names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partitionIDs', full_name='milvus.proto.milvus.ShowPartitionsResponse.partitionIDs', index=2,
      number=3, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2611,
  serialized_end=2727,
)


_DESCRIBESEGMENTREQUEST = _descriptor.Descriptor(
  name='DescribeSegmentRequest',
  full_name='milvus.proto.milvus.DescribeSegmentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.DescribeSegmentRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collectionID', full_name='milvus.proto.milvus.DescribeSegmentRequest.collectionID', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='segmentID', full_name='milvus.proto.milvus.DescribeSegmentRequest.segmentID', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2729,
  serialized_end=2838,
)


_DESCRIBESEGMENTRESPONSE = _descriptor.Descriptor(
  name='DescribeSegmentResponse',
  full_name='milvus.proto.milvus.DescribeSegmentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.milvus.DescribeSegmentResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='indexID', full_name='milvus.proto.milvus.DescribeSegmentResponse.indexID', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='buildID', full_name='milvus.proto.milvus.DescribeSegmentResponse.buildID', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enable_index', full_name='milvus.proto.milvus.DescribeSegmentResponse.enable_index', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2840,
  serialized_end=2966,
)


_SHOWSEGMENTSREQUEST = _descriptor.Descriptor(
  name='ShowSegmentsRequest',
  full_name='milvus.proto.milvus.ShowSegmentsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.ShowSegmentsRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collectionID', full_name='milvus.proto.milvus.ShowSegmentsRequest.collectionID', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partitionID', full_name='milvus.proto.milvus.ShowSegmentsRequest.partitionID', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2968,
  serialized_end=3076,
)


_SHOWSEGMENTSRESPONSE = _descriptor.Descriptor(
  name='ShowSegmentsResponse',
  full_name='milvus.proto.milvus.ShowSegmentsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.milvus.ShowSegmentsResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='segmentIDs', full_name='milvus.proto.milvus.ShowSegmentsResponse.segmentIDs', index=1,
      number=2, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3078,
  serialized_end=3165,
)


_CREATEINDEXREQUEST = _descriptor.Descriptor(
  name='CreateIndexRequest',
  full_name='milvus.proto.milvus.CreateIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.CreateIndexRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.CreateIndexRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.CreateIndexRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field_name', full_name='milvus.proto.milvus.CreateIndexRequest.field_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extra_params', full_name='milvus.proto.milvus.CreateIndexRequest.extra_params', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3168,
  serialized_end=3351,
)


_DESCRIBEINDEXREQUEST = _descriptor.Descriptor(
  name='DescribeIndexRequest',
  full_name='milvus.proto.milvus.DescribeIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.DescribeIndexRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.DescribeIndexRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.DescribeIndexRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field_name', full_name='milvus.proto.milvus.DescribeIndexRequest.field_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index_name', full_name='milvus.proto.milvus.DescribeIndexRequest.index_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3354,
  serialized_end=3502,
)


_INDEXDESCRIPTION = _descriptor.Descriptor(
  name='IndexDescription',
  full_name='milvus.proto.milvus.IndexDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index_name', full_name='milvus.proto.milvus.IndexDescription.index_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='indexID', full_name='milvus.proto.milvus.IndexDescription.indexID', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='params', full_name='milvus.proto.milvus.IndexDescription.params', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3504,
  serialized_end=3610,
)


_DESCRIBEINDEXRESPONSE = _descriptor.Descriptor(
  name='DescribeIndexResponse',
  full_name='milvus.proto.milvus.DescribeIndexResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.milvus.DescribeIndexResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index_descriptions', full_name='milvus.proto.milvus.DescribeIndexResponse.index_descriptions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3613,
  serialized_end=3748,
)


_GETINDEXSTATEREQUEST = _descriptor.Descriptor(
  name='GetIndexStateRequest',
  full_name='milvus.proto.milvus.GetIndexStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.GetIndexStateRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.GetIndexStateRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.GetIndexStateRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field_name', full_name='milvus.proto.milvus.GetIndexStateRequest.field_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index_name', full_name='milvus.proto.milvus.GetIndexStateRequest.index_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3751,
  serialized_end=3899,
)


_GETINDEXSTATERESPONSE = _descriptor.Descriptor(
  name='GetIndexStateResponse',
  full_name='milvus.proto.milvus.GetIndexStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.milvus.GetIndexStateResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='milvus.proto.milvus.GetIndexStateResponse.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3901,
  serialized_end=4017,
)


_DROPINDEXREQUEST = _descriptor.Descriptor(
  name='DropIndexRequest',
  full_name='milvus.proto.milvus.DropIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.DropIndexRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.DropIndexRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.DropIndexRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field_name', full_name='milvus.proto.milvus.DropIndexRequest.field_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index_name', full_name='milvus.proto.milvus.DropIndexRequest.index_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4020,
  serialized_end=4164,
)


_INSERTREQUEST = _descriptor.Descriptor(
  name='InsertRequest',
  full_name='milvus.proto.milvus.InsertRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.InsertRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.InsertRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.InsertRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partition_name', full_name='milvus.proto.milvus.InsertRequest.partition_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_data', full_name='milvus.proto.milvus.InsertRequest.row_data', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hash_keys', full_name='milvus.proto.milvus.InsertRequest.hash_keys', index=5,
      number=6, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4167,
  serialized_end=4356,
)


_INSERTRESPONSE = _descriptor.Descriptor(
  name='InsertResponse',
  full_name='milvus.proto.milvus.InsertResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.milvus.InsertResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rowID_begin', full_name='milvus.proto.milvus.InsertResponse.rowID_begin', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rowID_end', full_name='milvus.proto.milvus.InsertResponse.rowID_end', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4358,
  serialized_end=4459,
)


_PLACEHOLDERVALUE = _descriptor.Descriptor(
  name='PlaceholderValue',
  full_name='milvus.proto.milvus.PlaceholderValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag', full_name='milvus.proto.milvus.PlaceholderValue.tag', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='milvus.proto.milvus.PlaceholderValue.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='milvus.proto.milvus.PlaceholderValue.values', index=2,
      number=3, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4461,
  serialized_end=4560,
)


_PLACEHOLDERGROUP = _descriptor.Descriptor(
  name='PlaceholderGroup',
  full_name='milvus.proto.milvus.PlaceholderGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='placeholders', full_name='milvus.proto.milvus.PlaceholderGroup.placeholders', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4562,
  serialized_end=4641,
)


_SEARCHREQUEST = _descriptor.Descriptor(
  name='SearchRequest',
  full_name='milvus.proto.milvus.SearchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.SearchRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.SearchRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.milvus.SearchRequest.collection_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partition_names', full_name='milvus.proto.milvus.SearchRequest.partition_names', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dsl', full_name='milvus.proto.milvus.SearchRequest.dsl', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='placeholder_group', full_name='milvus.proto.milvus.SearchRequest.placeholder_group', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4644,
  serialized_end=4810,
)


_HITS = _descriptor.Descriptor(
  name='Hits',
  full_name='milvus.proto.milvus.Hits',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='IDs', full_name='milvus.proto.milvus.Hits.IDs', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_data', full_name='milvus.proto.milvus.Hits.row_data', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scores', full_name='milvus.proto.milvus.Hits.scores', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4812,
  serialized_end=4865,
)


_SEARCHRESULTS = _descriptor.Descriptor(
  name='SearchResults',
  full_name='milvus.proto.milvus.SearchResults',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.milvus.SearchResults.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hits', full_name='milvus.proto.milvus.SearchResults.hits', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4867,
  serialized_end=4941,
)


_FLUSHREQUEST = _descriptor.Descriptor(
  name='FlushRequest',
  full_name='milvus.proto.milvus.FlushRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.FlushRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='db_name', full_name='milvus.proto.milvus.FlushRequest.db_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_names', full_name='milvus.proto.milvus.FlushRequest.collection_names', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4943,
  serialized_end=5044,
)


_PERSISTENTSEGMENTINFO = _descriptor.Descriptor(
  name='PersistentSegmentInfo',
  full_name='milvus.proto.milvus.PersistentSegmentInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='segmentID', full_name='milvus.proto.milvus.PersistentSegmentInfo.segmentID', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collectionID', full_name='milvus.proto.milvus.PersistentSegmentInfo.collectionID', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partitionID', full_name='milvus.proto.milvus.PersistentSegmentInfo.partitionID', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open_time', full_name='milvus.proto.milvus.PersistentSegmentInfo.open_time', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sealed_time', full_name='milvus.proto.milvus.PersistentSegmentInfo.sealed_time', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flushed_time', full_name='milvus.proto.milvus.PersistentSegmentInfo.flushed_time', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_rows', full_name='milvus.proto.milvus.PersistentSegmentInfo.num_rows', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mem_size', full_name='milvus.proto.milvus.PersistentSegmentInfo.mem_size', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='milvus.proto.milvus.PersistentSegmentInfo.state', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5047,
  serialized_end=5280,
)


_GETPERSISTENTSEGMENTINFOREQUEST = _descriptor.Descriptor(
  name='GetPersistentSegmentInfoRequest',
  full_name='milvus.proto.milvus.GetPersistentSegmentInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.GetPersistentSegmentInfoRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dbName', full_name='milvus.proto.milvus.GetPersistentSegmentInfoRequest.dbName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collectionName', full_name='milvus.proto.milvus.GetPersistentSegmentInfoRequest.collectionName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5282,
  serialized_end=5399,
)


_GETPERSISTENTSEGMENTINFORESPONSE = _descriptor.Descriptor(
  name='GetPersistentSegmentInfoResponse',
  full_name='milvus.proto.milvus.GetPersistentSegmentInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.milvus.GetPersistentSegmentInfoResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='infos', full_name='milvus.proto.milvus.GetPersistentSegmentInfoResponse.infos', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5402,
  serialized_end=5540,
)


_QUERYSEGMENTINFO = _descriptor.Descriptor(
  name='QuerySegmentInfo',
  full_name='milvus.proto.milvus.QuerySegmentInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='segmentID', full_name='milvus.proto.milvus.QuerySegmentInfo.segmentID', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collectionID', full_name='milvus.proto.milvus.QuerySegmentInfo.collectionID', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partitionID', full_name='milvus.proto.milvus.QuerySegmentInfo.partitionID', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mem_size', full_name='milvus.proto.milvus.QuerySegmentInfo.mem_size', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_rows', full_name='milvus.proto.milvus.QuerySegmentInfo.num_rows', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index_name', full_name='milvus.proto.milvus.QuerySegmentInfo.index_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='indexID', full_name='milvus.proto.milvus.QuerySegmentInfo.indexID', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5543,
  serialized_end=5696,
)


_GETQUERYSEGMENTINFOREQUEST = _descriptor.Descriptor(
  name='GetQuerySegmentInfoRequest',
  full_name='milvus.proto.milvus.GetQuerySegmentInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='milvus.proto.milvus.GetQuerySegmentInfoRequest.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dbName', full_name='milvus.proto.milvus.GetQuerySegmentInfoRequest.dbName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collectionName', full_name='milvus.proto.milvus.GetQuerySegmentInfoRequest.collectionName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5698,
  serialized_end=5810,
)


_GETQUERYSEGMENTINFORESPONSE = _descriptor.Descriptor(
  name='GetQuerySegmentInfoResponse',
  full_name='milvus.proto.milvus.GetQuerySegmentInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.milvus.GetQuerySegmentInfoResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='infos', full_name='milvus.proto.milvus.GetQuerySegmentInfoResponse.infos', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5813,
  serialized_end=5941,
)


_REGISTERLINKREQUEST = _descriptor.Descriptor(
  name='RegisterLinkRequest',
  full_name='milvus.proto.milvus.RegisterLinkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5943,
  serialized_end=5964,
)


_REGISTERLINKRESPONSE = _descriptor.Descriptor(
  name='RegisterLinkResponse',
  full_name='milvus.proto.milvus.RegisterLinkResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='milvus.proto.milvus.RegisterLinkResponse.address', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.milvus.RegisterLinkResponse.status', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5966,
  serialized_end=6080,
)

_CREATECOLLECTIONREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_DROPCOLLECTIONREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_HASCOLLECTIONREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_BOOLRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_STRINGRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_DESCRIBECOLLECTIONREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_DESCRIBECOLLECTIONRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_DESCRIBECOLLECTIONRESPONSE.fields_by_name['schema'].message_type = schema__pb2._COLLECTIONSCHEMA
_LOADCOLLECTIONREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_RELEASECOLLECTIONREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_GETCOLLECTIONSTATISTICSREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_GETCOLLECTIONSTATISTICSRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_GETCOLLECTIONSTATISTICSRESPONSE.fields_by_name['stats'].message_type = common__pb2._KEYVALUEPAIR
_SHOWCOLLECTIONSREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_SHOWCOLLECTIONSRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_CREATEPARTITIONREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_DROPPARTITIONREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_HASPARTITIONREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_LOADPARTITIONSREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_RELEASEPARTITIONSREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_GETPARTITIONSTATISTICSREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_GETPARTITIONSTATISTICSRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_GETPARTITIONSTATISTICSRESPONSE.fields_by_name['stats'].message_type = common__pb2._KEYVALUEPAIR
_SHOWPARTITIONSREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_SHOWPARTITIONSRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_DESCRIBESEGMENTREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_DESCRIBESEGMENTRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_SHOWSEGMENTSREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_SHOWSEGMENTSRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_CREATEINDEXREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_CREATEINDEXREQUEST.fields_by_name['extra_params'].message_type = common__pb2._KEYVALUEPAIR
_DESCRIBEINDEXREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_INDEXDESCRIPTION.fields_by_name['params'].message_type = common__pb2._KEYVALUEPAIR
_DESCRIBEINDEXRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_DESCRIBEINDEXRESPONSE.fields_by_name['index_descriptions'].message_type = _INDEXDESCRIPTION
_GETINDEXSTATEREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_GETINDEXSTATERESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_GETINDEXSTATERESPONSE.fields_by_name['state'].enum_type = common__pb2._INDEXSTATE
_DROPINDEXREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_INSERTREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_INSERTREQUEST.fields_by_name['row_data'].message_type = common__pb2._BLOB
_INSERTRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_PLACEHOLDERVALUE.fields_by_name['type'].enum_type = _PLACEHOLDERTYPE
_PLACEHOLDERGROUP.fields_by_name['placeholders'].message_type = _PLACEHOLDERVALUE
_SEARCHREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_SEARCHRESULTS.fields_by_name['status'].message_type = common__pb2._STATUS
_FLUSHREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_PERSISTENTSEGMENTINFO.fields_by_name['state'].enum_type = common__pb2._SEGMENTSTATE
_GETPERSISTENTSEGMENTINFOREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_GETPERSISTENTSEGMENTINFORESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_GETPERSISTENTSEGMENTINFORESPONSE.fields_by_name['infos'].message_type = _PERSISTENTSEGMENTINFO
_GETQUERYSEGMENTINFOREQUEST.fields_by_name['base'].message_type = common__pb2._MSGBASE
_GETQUERYSEGMENTINFORESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_GETQUERYSEGMENTINFORESPONSE.fields_by_name['infos'].message_type = _QUERYSEGMENTINFO
_REGISTERLINKRESPONSE.fields_by_name['address'].message_type = common__pb2._ADDRESS
_REGISTERLINKRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
DESCRIPTOR.message_types_by_name['CreateCollectionRequest'] = _CREATECOLLECTIONREQUEST
DESCRIPTOR.message_types_by_name['DropCollectionRequest'] = _DROPCOLLECTIONREQUEST
DESCRIPTOR.message_types_by_name['HasCollectionRequest'] = _HASCOLLECTIONREQUEST
DESCRIPTOR.message_types_by_name['BoolResponse'] = _BOOLRESPONSE
DESCRIPTOR.message_types_by_name['StringResponse'] = _STRINGRESPONSE
DESCRIPTOR.message_types_by_name['DescribeCollectionRequest'] = _DESCRIBECOLLECTIONREQUEST
DESCRIPTOR.message_types_by_name['DescribeCollectionResponse'] = _DESCRIBECOLLECTIONRESPONSE
DESCRIPTOR.message_types_by_name['LoadCollectionRequest'] = _LOADCOLLECTIONREQUEST
DESCRIPTOR.message_types_by_name['ReleaseCollectionRequest'] = _RELEASECOLLECTIONREQUEST
DESCRIPTOR.message_types_by_name['GetCollectionStatisticsRequest'] = _GETCOLLECTIONSTATISTICSREQUEST
DESCRIPTOR.message_types_by_name['GetCollectionStatisticsResponse'] = _GETCOLLECTIONSTATISTICSRESPONSE
DESCRIPTOR.message_types_by_name['ShowCollectionsRequest'] = _SHOWCOLLECTIONSREQUEST
DESCRIPTOR.message_types_by_name['ShowCollectionsResponse'] = _SHOWCOLLECTIONSRESPONSE
DESCRIPTOR.message_types_by_name['CreatePartitionRequest'] = _CREATEPARTITIONREQUEST
DESCRIPTOR.message_types_by_name['DropPartitionRequest'] = _DROPPARTITIONREQUEST
DESCRIPTOR.message_types_by_name['HasPartitionRequest'] = _HASPARTITIONREQUEST
DESCRIPTOR.message_types_by_name['LoadPartitionsRequest'] = _LOADPARTITIONSREQUEST
DESCRIPTOR.message_types_by_name['ReleasePartitionsRequest'] = _RELEASEPARTITIONSREQUEST
DESCRIPTOR.message_types_by_name['GetPartitionStatisticsRequest'] = _GETPARTITIONSTATISTICSREQUEST
DESCRIPTOR.message_types_by_name['GetPartitionStatisticsResponse'] = _GETPARTITIONSTATISTICSRESPONSE
DESCRIPTOR.message_types_by_name['ShowPartitionsRequest'] = _SHOWPARTITIONSREQUEST
DESCRIPTOR.message_types_by_name['ShowPartitionsResponse'] = _SHOWPARTITIONSRESPONSE
DESCRIPTOR.message_types_by_name['DescribeSegmentRequest'] = _DESCRIBESEGMENTREQUEST
DESCRIPTOR.message_types_by_name['DescribeSegmentResponse'] = _DESCRIBESEGMENTRESPONSE
DESCRIPTOR.message_types_by_name['ShowSegmentsRequest'] = _SHOWSEGMENTSREQUEST
DESCRIPTOR.message_types_by_name['ShowSegmentsResponse'] = _SHOWSEGMENTSRESPONSE
DESCRIPTOR.message_types_by_name['CreateIndexRequest'] = _CREATEINDEXREQUEST
DESCRIPTOR.message_types_by_name['DescribeIndexRequest'] = _DESCRIBEINDEXREQUEST
DESCRIPTOR.message_types_by_name['IndexDescription'] = _INDEXDESCRIPTION
DESCRIPTOR.message_types_by_name['DescribeIndexResponse'] = _DESCRIBEINDEXRESPONSE
DESCRIPTOR.message_types_by_name['GetIndexStateRequest'] = _GETINDEXSTATEREQUEST
DESCRIPTOR.message_types_by_name['GetIndexStateResponse'] = _GETINDEXSTATERESPONSE
DESCRIPTOR.message_types_by_name['DropIndexRequest'] = _DROPINDEXREQUEST
DESCRIPTOR.message_types_by_name['InsertRequest'] = _INSERTREQUEST
DESCRIPTOR.message_types_by_name['InsertResponse'] = _INSERTRESPONSE
DESCRIPTOR.message_types_by_name['PlaceholderValue'] = _PLACEHOLDERVALUE
DESCRIPTOR.message_types_by_name['PlaceholderGroup'] = _PLACEHOLDERGROUP
DESCRIPTOR.message_types_by_name['SearchRequest'] = _SEARCHREQUEST
DESCRIPTOR.message_types_by_name['Hits'] = _HITS
DESCRIPTOR.message_types_by_name['SearchResults'] = _SEARCHRESULTS
DESCRIPTOR.message_types_by_name['FlushRequest'] = _FLUSHREQUEST
DESCRIPTOR.message_types_by_name['PersistentSegmentInfo'] = _PERSISTENTSEGMENTINFO
DESCRIPTOR.message_types_by_name['GetPersistentSegmentInfoRequest'] = _GETPERSISTENTSEGMENTINFOREQUEST
DESCRIPTOR.message_types_by_name['GetPersistentSegmentInfoResponse'] = _GETPERSISTENTSEGMENTINFORESPONSE
DESCRIPTOR.message_types_by_name['QuerySegmentInfo'] = _QUERYSEGMENTINFO
DESCRIPTOR.message_types_by_name['GetQuerySegmentInfoRequest'] = _GETQUERYSEGMENTINFOREQUEST
DESCRIPTOR.message_types_by_name['GetQuerySegmentInfoResponse'] = _GETQUERYSEGMENTINFORESPONSE
DESCRIPTOR.message_types_by_name['RegisterLinkRequest'] = _REGISTERLINKREQUEST
DESCRIPTOR.message_types_by_name['RegisterLinkResponse'] = _REGISTERLINKRESPONSE
DESCRIPTOR.enum_types_by_name['PlaceholderType'] = _PLACEHOLDERTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateCollectionRequest = _reflection.GeneratedProtocolMessageType('CreateCollectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECOLLECTIONREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.CreateCollectionRequest)
  })
_sym_db.RegisterMessage(CreateCollectionRequest)

DropCollectionRequest = _reflection.GeneratedProtocolMessageType('DropCollectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DROPCOLLECTIONREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.DropCollectionRequest)
  })
_sym_db.RegisterMessage(DropCollectionRequest)

HasCollectionRequest = _reflection.GeneratedProtocolMessageType('HasCollectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _HASCOLLECTIONREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.HasCollectionRequest)
  })
_sym_db.RegisterMessage(HasCollectionRequest)

BoolResponse = _reflection.GeneratedProtocolMessageType('BoolResponse', (_message.Message,), {
  'DESCRIPTOR' : _BOOLRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.BoolResponse)
  })
_sym_db.RegisterMessage(BoolResponse)

StringResponse = _reflection.GeneratedProtocolMessageType('StringResponse', (_message.Message,), {
  'DESCRIPTOR' : _STRINGRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.StringResponse)
  })
_sym_db.RegisterMessage(StringResponse)

DescribeCollectionRequest = _reflection.GeneratedProtocolMessageType('DescribeCollectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBECOLLECTIONREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.DescribeCollectionRequest)
  })
_sym_db.RegisterMessage(DescribeCollectionRequest)

DescribeCollectionResponse = _reflection.GeneratedProtocolMessageType('DescribeCollectionResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBECOLLECTIONRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.DescribeCollectionResponse)
  })
_sym_db.RegisterMessage(DescribeCollectionResponse)

LoadCollectionRequest = _reflection.GeneratedProtocolMessageType('LoadCollectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOADCOLLECTIONREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.LoadCollectionRequest)
  })
_sym_db.RegisterMessage(LoadCollectionRequest)

ReleaseCollectionRequest = _reflection.GeneratedProtocolMessageType('ReleaseCollectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _RELEASECOLLECTIONREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ReleaseCollectionRequest)
  })
_sym_db.RegisterMessage(ReleaseCollectionRequest)

GetCollectionStatisticsRequest = _reflection.GeneratedProtocolMessageType('GetCollectionStatisticsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCOLLECTIONSTATISTICSREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GetCollectionStatisticsRequest)
  })
_sym_db.RegisterMessage(GetCollectionStatisticsRequest)

GetCollectionStatisticsResponse = _reflection.GeneratedProtocolMessageType('GetCollectionStatisticsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCOLLECTIONSTATISTICSRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GetCollectionStatisticsResponse)
  })
_sym_db.RegisterMessage(GetCollectionStatisticsResponse)

ShowCollectionsRequest = _reflection.GeneratedProtocolMessageType('ShowCollectionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SHOWCOLLECTIONSREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ShowCollectionsRequest)
  })
_sym_db.RegisterMessage(ShowCollectionsRequest)

ShowCollectionsResponse = _reflection.GeneratedProtocolMessageType('ShowCollectionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _SHOWCOLLECTIONSRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ShowCollectionsResponse)
  })
_sym_db.RegisterMessage(ShowCollectionsResponse)

CreatePartitionRequest = _reflection.GeneratedProtocolMessageType('CreatePartitionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPARTITIONREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.CreatePartitionRequest)
  })
_sym_db.RegisterMessage(CreatePartitionRequest)

DropPartitionRequest = _reflection.GeneratedProtocolMessageType('DropPartitionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DROPPARTITIONREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.DropPartitionRequest)
  })
_sym_db.RegisterMessage(DropPartitionRequest)

HasPartitionRequest = _reflection.GeneratedProtocolMessageType('HasPartitionRequest', (_message.Message,), {
  'DESCRIPTOR' : _HASPARTITIONREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.HasPartitionRequest)
  })
_sym_db.RegisterMessage(HasPartitionRequest)

LoadPartitionsRequest = _reflection.GeneratedProtocolMessageType('LoadPartitionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOADPARTITIONSREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.LoadPartitionsRequest)
  })
_sym_db.RegisterMessage(LoadPartitionsRequest)

ReleasePartitionsRequest = _reflection.GeneratedProtocolMessageType('ReleasePartitionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _RELEASEPARTITIONSREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ReleasePartitionsRequest)
  })
_sym_db.RegisterMessage(ReleasePartitionsRequest)

GetPartitionStatisticsRequest = _reflection.GeneratedProtocolMessageType('GetPartitionStatisticsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPARTITIONSTATISTICSREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GetPartitionStatisticsRequest)
  })
_sym_db.RegisterMessage(GetPartitionStatisticsRequest)

GetPartitionStatisticsResponse = _reflection.GeneratedProtocolMessageType('GetPartitionStatisticsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPARTITIONSTATISTICSRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GetPartitionStatisticsResponse)
  })
_sym_db.RegisterMessage(GetPartitionStatisticsResponse)

ShowPartitionsRequest = _reflection.GeneratedProtocolMessageType('ShowPartitionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SHOWPARTITIONSREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ShowPartitionsRequest)
  })
_sym_db.RegisterMessage(ShowPartitionsRequest)

ShowPartitionsResponse = _reflection.GeneratedProtocolMessageType('ShowPartitionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _SHOWPARTITIONSRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ShowPartitionsResponse)
  })
_sym_db.RegisterMessage(ShowPartitionsResponse)

DescribeSegmentRequest = _reflection.GeneratedProtocolMessageType('DescribeSegmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESEGMENTREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.DescribeSegmentRequest)
  })
_sym_db.RegisterMessage(DescribeSegmentRequest)

DescribeSegmentResponse = _reflection.GeneratedProtocolMessageType('DescribeSegmentResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESEGMENTRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.DescribeSegmentResponse)
  })
_sym_db.RegisterMessage(DescribeSegmentResponse)

ShowSegmentsRequest = _reflection.GeneratedProtocolMessageType('ShowSegmentsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SHOWSEGMENTSREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ShowSegmentsRequest)
  })
_sym_db.RegisterMessage(ShowSegmentsRequest)

ShowSegmentsResponse = _reflection.GeneratedProtocolMessageType('ShowSegmentsResponse', (_message.Message,), {
  'DESCRIPTOR' : _SHOWSEGMENTSRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.ShowSegmentsResponse)
  })
_sym_db.RegisterMessage(ShowSegmentsResponse)

CreateIndexRequest = _reflection.GeneratedProtocolMessageType('CreateIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEINDEXREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.CreateIndexRequest)
  })
_sym_db.RegisterMessage(CreateIndexRequest)

DescribeIndexRequest = _reflection.GeneratedProtocolMessageType('DescribeIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEINDEXREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.DescribeIndexRequest)
  })
_sym_db.RegisterMessage(DescribeIndexRequest)

IndexDescription = _reflection.GeneratedProtocolMessageType('IndexDescription', (_message.Message,), {
  'DESCRIPTOR' : _INDEXDESCRIPTION,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.IndexDescription)
  })
_sym_db.RegisterMessage(IndexDescription)

DescribeIndexResponse = _reflection.GeneratedProtocolMessageType('DescribeIndexResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEINDEXRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.DescribeIndexResponse)
  })
_sym_db.RegisterMessage(DescribeIndexResponse)

GetIndexStateRequest = _reflection.GeneratedProtocolMessageType('GetIndexStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETINDEXSTATEREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GetIndexStateRequest)
  })
_sym_db.RegisterMessage(GetIndexStateRequest)

GetIndexStateResponse = _reflection.GeneratedProtocolMessageType('GetIndexStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETINDEXSTATERESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GetIndexStateResponse)
  })
_sym_db.RegisterMessage(GetIndexStateResponse)

DropIndexRequest = _reflection.GeneratedProtocolMessageType('DropIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _DROPINDEXREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.DropIndexRequest)
  })
_sym_db.RegisterMessage(DropIndexRequest)

InsertRequest = _reflection.GeneratedProtocolMessageType('InsertRequest', (_message.Message,), {
  'DESCRIPTOR' : _INSERTREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.InsertRequest)
  })
_sym_db.RegisterMessage(InsertRequest)

InsertResponse = _reflection.GeneratedProtocolMessageType('InsertResponse', (_message.Message,), {
  'DESCRIPTOR' : _INSERTRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.InsertResponse)
  })
_sym_db.RegisterMessage(InsertResponse)

PlaceholderValue = _reflection.GeneratedProtocolMessageType('PlaceholderValue', (_message.Message,), {
  'DESCRIPTOR' : _PLACEHOLDERVALUE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.PlaceholderValue)
  })
_sym_db.RegisterMessage(PlaceholderValue)

PlaceholderGroup = _reflection.GeneratedProtocolMessageType('PlaceholderGroup', (_message.Message,), {
  'DESCRIPTOR' : _PLACEHOLDERGROUP,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.PlaceholderGroup)
  })
_sym_db.RegisterMessage(PlaceholderGroup)

SearchRequest = _reflection.GeneratedProtocolMessageType('SearchRequest', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.SearchRequest)
  })
_sym_db.RegisterMessage(SearchRequest)

Hits = _reflection.GeneratedProtocolMessageType('Hits', (_message.Message,), {
  'DESCRIPTOR' : _HITS,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.Hits)
  })
_sym_db.RegisterMessage(Hits)

SearchResults = _reflection.GeneratedProtocolMessageType('SearchResults', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHRESULTS,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.SearchResults)
  })
_sym_db.RegisterMessage(SearchResults)

FlushRequest = _reflection.GeneratedProtocolMessageType('FlushRequest', (_message.Message,), {
  'DESCRIPTOR' : _FLUSHREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.FlushRequest)
  })
_sym_db.RegisterMessage(FlushRequest)

PersistentSegmentInfo = _reflection.GeneratedProtocolMessageType('PersistentSegmentInfo', (_message.Message,), {
  'DESCRIPTOR' : _PERSISTENTSEGMENTINFO,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.PersistentSegmentInfo)
  })
_sym_db.RegisterMessage(PersistentSegmentInfo)

GetPersistentSegmentInfoRequest = _reflection.GeneratedProtocolMessageType('GetPersistentSegmentInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPERSISTENTSEGMENTINFOREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GetPersistentSegmentInfoRequest)
  })
_sym_db.RegisterMessage(GetPersistentSegmentInfoRequest)

GetPersistentSegmentInfoResponse = _reflection.GeneratedProtocolMessageType('GetPersistentSegmentInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPERSISTENTSEGMENTINFORESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GetPersistentSegmentInfoResponse)
  })
_sym_db.RegisterMessage(GetPersistentSegmentInfoResponse)

QuerySegmentInfo = _reflection.GeneratedProtocolMessageType('QuerySegmentInfo', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSEGMENTINFO,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.QuerySegmentInfo)
  })
_sym_db.RegisterMessage(QuerySegmentInfo)

GetQuerySegmentInfoRequest = _reflection.GeneratedProtocolMessageType('GetQuerySegmentInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETQUERYSEGMENTINFOREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GetQuerySegmentInfoRequest)
  })
_sym_db.RegisterMessage(GetQuerySegmentInfoRequest)

GetQuerySegmentInfoResponse = _reflection.GeneratedProtocolMessageType('GetQuerySegmentInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETQUERYSEGMENTINFORESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.GetQuerySegmentInfoResponse)
  })
_sym_db.RegisterMessage(GetQuerySegmentInfoResponse)

RegisterLinkRequest = _reflection.GeneratedProtocolMessageType('RegisterLinkRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERLINKREQUEST,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.RegisterLinkRequest)
  })
_sym_db.RegisterMessage(RegisterLinkRequest)

RegisterLinkResponse = _reflection.GeneratedProtocolMessageType('RegisterLinkResponse', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERLINKRESPONSE,
  '__module__' : 'milvus_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.milvus.RegisterLinkResponse)
  })
_sym_db.RegisterMessage(RegisterLinkResponse)


DESCRIPTOR._options = None

_MILVUSSERVICE = _descriptor.ServiceDescriptor(
  name='MilvusService',
  full_name='milvus.proto.milvus.MilvusService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=6147,
  serialized_end=8720,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateCollection',
    full_name='milvus.proto.milvus.MilvusService.CreateCollection',
    index=0,
    containing_service=None,
    input_type=_CREATECOLLECTIONREQUEST,
    output_type=common__pb2._STATUS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DropCollection',
    full_name='milvus.proto.milvus.MilvusService.DropCollection',
    index=1,
    containing_service=None,
    input_type=_DROPCOLLECTIONREQUEST,
    output_type=common__pb2._STATUS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='HasCollection',
    full_name='milvus.proto.milvus.MilvusService.HasCollection',
    index=2,
    containing_service=None,
    input_type=_HASCOLLECTIONREQUEST,
    output_type=_BOOLRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='LoadCollection',
    full_name='milvus.proto.milvus.MilvusService.LoadCollection',
    index=3,
    containing_service=None,
    input_type=_LOADCOLLECTIONREQUEST,
    output_type=common__pb2._STATUS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ReleaseCollection',
    full_name='milvus.proto.milvus.MilvusService.ReleaseCollection',
    index=4,
    containing_service=None,
    input_type=_RELEASECOLLECTIONREQUEST,
    output_type=common__pb2._STATUS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeCollection',
    full_name='milvus.proto.milvus.MilvusService.DescribeCollection',
    index=5,
    containing_service=None,
    input_type=_DESCRIBECOLLECTIONREQUEST,
    output_type=_DESCRIBECOLLECTIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetCollectionStatistics',
    full_name='milvus.proto.milvus.MilvusService.GetCollectionStatistics',
    index=6,
    containing_service=None,
    input_type=_GETCOLLECTIONSTATISTICSREQUEST,
    output_type=_GETCOLLECTIONSTATISTICSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ShowCollections',
    full_name='milvus.proto.milvus.MilvusService.ShowCollections',
    index=7,
    containing_service=None,
    input_type=_SHOWCOLLECTIONSREQUEST,
    output_type=_SHOWCOLLECTIONSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CreatePartition',
    full_name='milvus.proto.milvus.MilvusService.CreatePartition',
    index=8,
    containing_service=None,
    input_type=_CREATEPARTITIONREQUEST,
    output_type=common__pb2._STATUS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DropPartition',
    full_name='milvus.proto.milvus.MilvusService.DropPartition',
    index=9,
    containing_service=None,
    input_type=_DROPPARTITIONREQUEST,
    output_type=common__pb2._STATUS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='HasPartition',
    full_name='milvus.proto.milvus.MilvusService.HasPartition',
    index=10,
    containing_service=None,
    input_type=_HASPARTITIONREQUEST,
    output_type=_BOOLRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='LoadPartitions',
    full_name='milvus.proto.milvus.MilvusService.LoadPartitions',
    index=11,
    containing_service=None,
    input_type=_LOADPARTITIONSREQUEST,
    output_type=common__pb2._STATUS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ReleasePartitions',
    full_name='milvus.proto.milvus.MilvusService.ReleasePartitions',
    index=12,
    containing_service=None,
    input_type=_RELEASEPARTITIONSREQUEST,
    output_type=common__pb2._STATUS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetPartitionStatistics',
    full_name='milvus.proto.milvus.MilvusService.GetPartitionStatistics',
    index=13,
    containing_service=None,
    input_type=_GETPARTITIONSTATISTICSREQUEST,
    output_type=_GETPARTITIONSTATISTICSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ShowPartitions',
    full_name='milvus.proto.milvus.MilvusService.ShowPartitions',
    index=14,
    containing_service=None,
    input_type=_SHOWPARTITIONSREQUEST,
    output_type=_SHOWPARTITIONSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CreateIndex',
    full_name='milvus.proto.milvus.MilvusService.CreateIndex',
    index=15,
    containing_service=None,
    input_type=_CREATEINDEXREQUEST,
    output_type=common__pb2._STATUS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeIndex',
    full_name='milvus.proto.milvus.MilvusService.DescribeIndex',
    index=16,
    containing_service=None,
    input_type=_DESCRIBEINDEXREQUEST,
    output_type=_DESCRIBEINDEXRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetIndexState',
    full_name='milvus.proto.milvus.MilvusService.GetIndexState',
    index=17,
    containing_service=None,
    input_type=_GETINDEXSTATEREQUEST,
    output_type=_GETINDEXSTATERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DropIndex',
    full_name='milvus.proto.milvus.MilvusService.DropIndex',
    index=18,
    containing_service=None,
    input_type=_DROPINDEXREQUEST,
    output_type=common__pb2._STATUS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Insert',
    full_name='milvus.proto.milvus.MilvusService.Insert',
    index=19,
    containing_service=None,
    input_type=_INSERTREQUEST,
    output_type=_INSERTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Search',
    full_name='milvus.proto.milvus.MilvusService.Search',
    index=20,
    containing_service=None,
    input_type=_SEARCHREQUEST,
    output_type=_SEARCHRESULTS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Flush',
    full_name='milvus.proto.milvus.MilvusService.Flush',
    index=21,
    containing_service=None,
    input_type=_FLUSHREQUEST,
    output_type=common__pb2._STATUS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetPersistentSegmentInfo',
    full_name='milvus.proto.milvus.MilvusService.GetPersistentSegmentInfo',
    index=22,
    containing_service=None,
    input_type=_GETPERSISTENTSEGMENTINFOREQUEST,
    output_type=_GETPERSISTENTSEGMENTINFORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetQuerySegmentInfo',
    full_name='milvus.proto.milvus.MilvusService.GetQuerySegmentInfo',
    index=23,
    containing_service=None,
    input_type=_GETQUERYSEGMENTINFOREQUEST,
    output_type=_GETQUERYSEGMENTINFORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RegisterLink',
    full_name='milvus.proto.milvus.MilvusService.RegisterLink',
    index=24,
    containing_service=None,
    input_type=_REGISTERLINKREQUEST,
    output_type=_REGISTERLINKRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_MILVUSSERVICE)

DESCRIPTOR.services_by_name['MilvusService'] = _MILVUSSERVICE


_PROXYSERVICE = _descriptor.ServiceDescriptor(
  name='ProxyService',
  full_name='milvus.proto.milvus.ProxyService',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  serialized_start=8722,
  serialized_end=8839,
  methods=[
  _descriptor.MethodDescriptor(
    name='RegisterLink',
    full_name='milvus.proto.milvus.ProxyService.RegisterLink',
    index=0,
    containing_service=None,
    input_type=_REGISTERLINKREQUEST,
    output_type=_REGISTERLINKRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_PROXYSERVICE)

DESCRIPTOR.services_by_name['ProxyService'] = _PROXYSERVICE

# @@protoc_insertion_point(module_scope)
